# Generated by Django 4.0.10 on 2023-09-22 23:00

# Django
from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("timezones", "0004_delete_aatimezones"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="timezonedata",
            options={
                "default_permissions": (),
                "verbose_name": "Timezone data",
                "verbose_name_plural": "Timezone data",
            },
        ),
    ]
