@media all {
    .aa-timezones .timezone-panel-section {
        display: block;
    }

    .aa-timezones .timezone-panel-section-time {
        font-size: 140%;
    }

    .aa-timezones .timezone-panel-section-utc-offset {
        font-size: 85%;
    }

    .aa-timezones .aa-timezones-time-until {
        font-size: 125%;
        font-weight: 600;
    }
}
