{% extends 'allianceauth/base-bs5.html' %}

{% load i18n %}

{% block page_title %}
    {% translate "Time Zones" %}
{% endblock %}

{% block header_nav_brand %}
    {% translate "Time Zones" %}
{% endblock header_nav_brand %}

{% block content %}
    <div class="aa-timezones">
        <div class="aa-timezones-body">
            {% block aa_timezones_body %}{% endblock %}
        </div>

        <div class="aa-timezones-footer mt-3 pt-3 border-top border-light">
            {% include "timezones/partials/footer/app-translation-footer.html" %}
        </div>
    </div>
{% endblock %}
